==> re2c_4.1.orig.tar.xz: re2c-4.1/test/config/no_syntax_file.c <==
<default syntax file>:1:0: warning: syntax configuration `code:var_local` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:var_global` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:const_local` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:const_global` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:array_local` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:array_global` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:array_elem` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:enum` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:enum_elem` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:assign` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:type_int` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:type_uint` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:type_yybm` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:type_yytarget` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cmp_eq` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cmp_ne` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cmp_lt` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cmp_gt` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cmp_le` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cmp_ge` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:if_then_else` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:if_then_else_oneline` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:switch` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:switch_cases` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:switch_cases_oneline` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:switch_case_range` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:switch_case_default` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:loop` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:continue` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:goto` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:fndecl` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:fndef` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:fncall` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:tailcall` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:recursive_functions` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:fingerprint` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:line_info` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:abort` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yydebug` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yypeek` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyskip` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybackup` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybackupctx` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyskip_yypeek` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yypeek_yyskip` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyskip_yybackup` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybackup_yyskip` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybackup_yypeek` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyskip_yybackup_yypeek` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybackup_yypeek_yyskip` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyrestore` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyrestorectx` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyrestoretag` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyshift` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyshiftstag` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyshiftmtag` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yystagp` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yymtagp` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yystagn` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yymtagn` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yycopystag` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yycopymtag` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yygetaccept` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yysetaccept` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yygetcond` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yysetcond` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yygetstate` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yysetstate` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yylessthan` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybm_filter` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybm_match` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
re2c: error: code model is not supported for this backend

==> re2c-4.3.tar.xz: re2c-4.3/test/config/no_syntax_file.c <==
<default syntax file>:1:0: warning: syntax configuration `code:var_local` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:var_global` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:const_local` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:const_global` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:array_local` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:array_global` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:array_elem` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:enum` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:enum_elem` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:assign` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:type_int` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:type_uint` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:type_yybm` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:type_yytarget` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:type_yyctable` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cmp_eq` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cmp_ne` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cmp_lt` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cmp_gt` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cmp_le` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cmp_ge` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:if_then_else` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:if_then_else_oneline` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:switch` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:switch_cases` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:switch_cases_oneline` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:switch_case_range` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:switch_case_default` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:loop` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:continue` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:goto` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cgoto` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:cgoto_data` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:fndecl` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:fndef` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:fncall` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:tailcall` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:recursive_functions` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:fingerprint` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:line_info` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:abort` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yydebug` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yypeek` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyskip` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybackup` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybackupctx` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyskip_yypeek` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yypeek_yyskip` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyskip_yybackup` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybackup_yyskip` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybackup_yypeek` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyskip_yybackup_yypeek` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybackup_yypeek_yyskip` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyrestore` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyrestorectx` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyrestoretag` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyshift` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyshiftstag` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yyshiftmtag` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yystagp` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yymtagp` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yystagn` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yymtagn` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yycopystag` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yycopymtag` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yygetaccept` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yysetaccept` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yygetcond` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yysetcond` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yygetstate` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yysetstate` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yylessthan` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybm_filter` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yybm_match` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
<default syntax file>:1:0: warning: syntax configuration `code:yytarget_filter` is not defined (set it to <undefined> explicitly to silence the warning) [-Wundefined-syntax-config]
re2c: error: code model is not supported for this backend
